"""
Image Renamer - Rename image files based on their creation date from EXIF metadata.
"""

__version__ = "1.1.8"
__author__ = "Lars van der Niet"
__license__ = "MIT"
__url__ = "https://github.com/larsniet/image-renamer"
